@@ -116,12 +116,15 @@ sub digestFile {
   }
   else {
     $request =~ s/\.\Q$MODE_EXTENSION{$mode}\E$//;
-    if (my $pathname = pathname_find($request, types => [$MODE_EXTENSION{$mode}, ''])) {
+    if (my $pathname = pathname_find($request, types => [$MODE_EXTENSION{$mode}, ''],
+                                   paths => $$self{state}->lookupValue('SEARCHPATHS'))) {
       $request = $pathname;
       ($dir, $name, $ext) = pathname_split($request); }
     else {
       $self->withState(sub {
-          Fatal('missing_file', $request, undef, "Can't find $mode file $request"); }); } }
+          Fatal('missing_file', $request, undef, "Can't find $mode file $request",
+                               LaTeXML::Package::maybeReportSearchPaths()
+                               ); }); } }
   return
     $self->withState(sub {
       my ($state) = @_;
