@@ -9,6 +9,7 @@ use FindBin;
 use File::Copy;
 use File::Which;
 use File::Spec::Functions;
+use File::Temp;
 use LaTeXML::Post;
 use LaTeXML::Post::MathML::Presentation;
 use LaTeXML::Post::XMath;
@@ -207,9 +208,12 @@ sub is_strings {
 sub daemon_ok {
   my ($base, $dir, $generate) = @_;
   my $current_dir = pathname_cwd();
+  File::Temp->safe_level(File::Temp::HIGH);
+  my $workdir = File::Temp->newdir("LaTeXMLXXXXXX", TMPDIR => 1);
   my $localname   = $base;
   $localname =~ s/$dir\///;
   my $opts = read_options("$base.spec", $base);
+  unshift(@$opts, ['path', pathname_concat($current_dir,pathname_directory($base))]);
   push @$opts, (['destination', "$localname.test.xml"],
     ['log',                "/dev/null"],
     ['timeout',            10],
@@ -229,29 +233,29 @@ sub daemon_ok {
   }
   $invocation .= " 2>$localname.test.status ";
   if (!$generate) {
-    pathname_chdir($dir);
+    pathname_chdir($workdir);
     is(system($invocation), 0, "latexmlc invocation for test $localname");
     pathname_chdir($current_dir);
     # Compare the just generated $base.test.xml to the previous $base.xml
-    if (my $teststrings = process_xmlfile("$base.test.xml", $base)) {
+    if (my $teststrings = process_xmlfile("$workdir/$localname.test.xml", $base)) {
       if (my $xmlstrings = process_xmlfile("$base.xml", $base)) {
         is_strings($teststrings, $xmlstrings, $base); } }
 
     # Compare the just generated $base.test.status to the previous $base.status
-    if (my $teststatus = get_filecontent("$base.test.status", $base)) {
+    if (my $teststatus = get_filecontent("$workdir/$localname.test.status", $base)) {
       if (my $status = get_filecontent("$base.status", $base)) {
         is_strings($teststatus, $status, $base); } }
-    unlink "$base.test.xml"    if -e "$base.test.xml";
-    unlink "$base.test.status" if -e "$base.test.status";
+    unlink "$workdir/$localname.test.xml"    if -e "$workdir/$localname.test.xml";
+    unlink "$workdir/$localname.test.status" if -e "$workdir/$localname.test.status";
   }
   else {
     #TODO: Skip 3 tests
     print STDERR "$invocation\n";
-    pathname_chdir($dir);
+    pathname_chdir($workdir);
     system($invocation);
     pathname_chdir($current_dir);
-    move("$base.test.xml",    "$base.xml")    if -e "$base.test.xml";
-    move("$base.test.status", "$base.status") if -e "$base.test.status";
+    move("$workdir/$localname.test.xml",    "$base.xml")    if -e "$workdir/$localname.test.xml";
+    move("$workdir/$localname.test.status", "$base.status") if -e "$workdir/$localname.test.status";
   }
   return; }
 
